@@ -5,7 +5,6 @@ from ._selenium import (
     CLIENT_SECRET,
     LOGIN_URL,
     REDIRECT_URI,
-    REQUESTS_KWARGS,
     USER_AGENT,
     GetPixivToken,
 )
@@ -19,7 +18,7 @@ from .login_response_types import (
     ProfileURIs,
 )
 
-__version__ = "2.2.1"
+__version__ = "3.1.0"
 
 __all__ = [
     "PixivAuth",
@@ -36,7 +35,6 @@ __all__ = [
     "CLIENT_SECRET",
     "LOGIN_URL",
     "REDIRECT_URI",
-    "REQUESTS_KWARGS",
     "USER_AGENT",
     "GetPixivToken",
 ]
